Changelog
=========

`1.0.1`_
--------

- fix category tags (see issue #1)

1.0.0
-----

- initial release

.. _Unreleased: https://github.com/adbenitez/simplebot/compare/v1.0.0...HEAD
.. _1.0.1: https://github.com/adbenitez/simplebot/compare/v1.0.0...v1.0.1
